@@ -1,9 +1,9 @@
 package WordList::Test::Dynamic::OneTwo_FirstNextReset;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-23'; # DATE
+our $DATE = '2021-03-05'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.8'; # VERSION
+our $VERSION = '0.7.9'; # VERSION
 
 use strict;
 
@@ -36,7 +36,7 @@ sub next_word {
     else { return undef }
 }
 
-our %STATS = ("num_words_contain_whitespace",0,"num_words",2,"num_words_contains_whitespace",0,"longest_word_len",3,"shortest_word_len",3,"num_words_contain_unicode",0,"avg_word_len",3,"num_words_contains_nonword_chars",0,"num_words_contain_nonword_chars",0,"num_words_contains_unicode",0); # STATS
+our %STATS = ("avg_word_len",3,"num_words_contain_nonword_chars",0,"num_words_contain_whitespace",0,"longest_word_len",3,"num_words_contain_unicode",0,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"shortest_word_len",3,"num_words",2,"num_words_contains_nonword_chars",0); # STATS
 
 1;
 # ABSTRACT: Wordlist that returns one, two (via implementing first_word(), next_word(), and reset_iterator())
@@ -53,7 +53,7 @@ WordList::Test::Dynamic::OneTwo_FirstNextReset - Wordlist that returns one, two
 
 =head1 VERSION
 
-This document describes version 0.7.8 of WordList::Test::Dynamic::OneTwo_FirstNextReset (from Perl distribution WordList), released on 2021-02-23.
+This document describes version 0.7.9 of WordList::Test::Dynamic::OneTwo_FirstNextReset (from Perl distribution WordList), released on 2021-03-05.
 
 =head1 SYNOPSIS
 
