@@ -1,12 +1,12 @@
 package WordList::Test::OneTwo;
 
-our $DATE = '2021-02-23'; # DATE
-our $VERSION = '0.7.8'; # VERSION
+our $DATE = '2021-03-05'; # DATE
+our $VERSION = '0.7.9'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("avg_word_len",3,"num_words_contain_unicode",0,"num_words_contains_whitespace",0,"shortest_word_len",3,"longest_word_len",3,"num_words",2,"num_words_contain_whitespace",0,"num_words_contains_unicode",0,"num_words_contain_nonword_chars",0,"num_words_contains_nonword_chars",0); # STATS
+our %STATS = ("num_words_contains_nonword_chars",0,"num_words",2,"shortest_word_len",3,"num_words_contains_unicode",0,"num_words_contains_whitespace",0,"num_words_contain_unicode",0,"longest_word_len",3,"num_words_contain_whitespace",0,"avg_word_len",3,"num_words_contain_nonword_chars",0); # STATS
 
 1;
 # ABSTRACT: Wordlist that contains "one" and "two"
@@ -21,7 +21,7 @@ WordList::Test::OneTwo - Wordlist that contains "one" and "two"
 
 =head1 VERSION
 
-This document describes version 0.7.8 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2021-02-23.
+This document describes version 0.7.9 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2021-03-05.
 
 =head1 SYNOPSIS
 
